Learn R Programming

NonCompart (version 0.2.4)

IndiNCA: Noncompartmental Analysis for an Individual

Description

It performs a noncompartmental analysis with one subject data

Usage

IndiNCA(x, y, Dose = 0, Method = "Linear", AdmMode = "Extravascular", TimeInfusion = 0, RetNames, Report = "Table", iAUC)

Arguments

x
vector values of independent variable, usually time
y
vector values of dependent variable, usually concentration
Dose
administered dose for the subject
Method
either of "Linear" or "Log" to indicate the way to calculate AUC and AUMC
AdmMode
one of "Bolus" or "Infusion" or "Extravascular" to indicate drug administration mode
TimeInfusion
infusion duration for constant infusion, otherwise 0
RetNames
character vector for the pharmacokinetic parameter names to be returned
Report
either of "Table" or "Text" to specify the type of return value
iAUC
data.frame with three columns, "Name", "Start", "End" to specify the invervals for partial (interval) AUC

Value

Details

This performs a noncompartmental analysis for a subject. It returns practically the same result with the most popular commercial software.

References

  1. Gabrielsson J, Weiner D. Pharmacokinetic and Pharmacodynamic Data Analysis - Concepts and Applications. 5th ed. 2016.
  2. Shargel L, Yu A. Applied Biopharmaceutics and Pharmacokinetics. 7th ed. 2015.
  3. Rowland M, Tozer TN. Clinical Pharmacokinetics and Pharmacodynamics - Concepts and Applications. 4th ed. 2011.
  4. Gibaldi M, Perrier D. Pharmacokinetics. 2nd ed. revised and expanded. 1982.

See Also

AUC, BestSlope

Examples

Run this code
IndiNCA(Theoph[Theoph$Subject==1,"Time"], Theoph[Theoph$Subject==1, "conc"], Dose=320)
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Bolus")
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Infusion", TimeInfusion=0.25)

IndiNCA(Theoph[Theoph$Subject==1,"Time"], Theoph[Theoph$Subject==1, "conc"], Dose=320,
        Report="Text")
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Bolus", Report="Text")
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Infusion", TimeInfusion=0.25, Report="Text")

iAUC = data.frame(Name=c("AUC[0-12h]","AUC[0-24h]"), Start=c(0,0), End=c(12,24)) ; iAUC
IndiNCA(Theoph[Theoph$Subject==1,"Time"], Theoph[Theoph$Subject==1, "conc"], Dose=320,
        iAUC=iAUC)
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Bolus", iAUC=iAUC)
IndiNCA(Indometh[Indometh$Subject==1,"time"], Indometh[Indometh$Subject==1, "conc"], Dose=25,
        AdmMode="Infusion", TimeInfusion=0.25, iAUC=iAUC)

Run the code above in your browser using DataLab