Learn R Programming

NonCompart (version 0.2.4)

NCA: Noncompartmental analysis for a dataset with multiple subjects

Description

conduct noncompartmental analysis for many subjects in a data table

Usage

NCA(Data, colSubj, colTime, colConc, colTrt, Method = "Linear", Dose = 0, AdmMode = "Extravascular", TimeInfusion = 0, Report = "Table", iAUC)

Arguments

Data
name of data table containing time-concentration data of multiple subjects
colSubj
column name for subject ID
colTime
column name for the time
colConc
column name for the concentration
colTrt
column name for the treatment code. This is useful for crossover study like bioequivalence trial.
Method
one of "Linear" or "Log" to indicate the way to calculate AUC
Dose
administered dose. One should be careful for the unit. This can be a vector containing dose for each subject in order.
AdmMode
one of "Bolus" or "Infusion" or "Extravascular" to indicate drug administration mode
TimeInfusion
infusion duration for constant infusion, otherwise 0. This can be a vector containing values for each subject in order.
Report
either of "Table" or "Text" to specify the type of return value
iAUC
data.frame with three columns, "Name", "Start", "End" to specify partial interval AUC

Value

Details

This function calls IndiNCA repeatedly to do NCA for each subject. If you specify Report="Text", this function returns in free text format to be used in a report file.

References

  1. Gabrielsson J, Weiner D. Pharmacokinetic and Pharmacodynamic Data Analysis - Concepts and Applications. 5th ed. 2016.
  2. Shargel L, Yu A. Applied Biopharmaceutics and Pharmacokinetics. 7th ed. 2015.
  3. Rowland M, Tozer TN. Clinical Pharmacokinetics and Pharmacodynamics - Concepts and Applications. 4th ed. 2011.
  4. Gibaldi M, Perrier D. Pharmacokinetics. 2nd ed. revised and expanded. 1982.

See Also

IndiNCA

Examples

Run this code
# Theoph and Indometh data: dose in mg, conc in mg/L, time in h
NCA(Theoph, "Subject", "Time", "conc", Dose=320)
NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Bolus")

iAUC = data.frame(Name=c("AUC[0-12h]","AUC[0-24h]"), Start=c(0,0), End=c(12,24)) ; iAUC
NCA(Theoph, "Subject", "Time", "conc", Dose=320, iAUC=iAUC)
NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Bolus", iAUC=iAUC)

writeLines(NCA(Theoph, "Subject", "Time", "conc", Dose=320, Report="Text"),
           "Theoph_Linear_CoreOutput.txt")
writeLines(NCA(Theoph, "Subject", "Time", "conc", Dose=320, Method="Log", Report="Text"),
           "Theoph_Log_CoreOutput.txt")
writeLines(NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Bolus", Report="Text"),
           "Indometh_Bolus_Linear_CoreOutput.txt")
writeLines(NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Bolus", Method="Log",
           Report="Text"), "Indometh_Bolus_Log_CoreOutput.txt")
writeLines(NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Infusion", TimeInfusion=0.25,
           Report="Text"), "Indometh_Infusion_Linear_CoreOutput.txt")
writeLines(NCA(Indometh, "Subject", "time", "conc", Dose=25, AdmMode="Infusion", TimeInfusion=0.25,
           Method="Log", Report="Text"), "Indometh_Infusion_Log_CoreOutput.txt")

Run the code above in your browser using DataLab