Learn R Programming

NonCompart (version 0.2.4)

RptCfg: NCA Report Configuation Table

Description

Contains the names and order of colum of return table/text by IndiNCA and NCA functions

Usage

RptCfg

Arguments

Format

A data frame with 48 observations on the following 10 variables.

Details

This table should exist in NonCompart package. User can edit this table for shaping the report in one's own style.