Learn R Programming

NonCompart (version 0.2.6)

Slope: Get the Slope of regression log(y) ~ x

Description

It calculates the slope with linear regression of log(y) ~ x

Usage

Slope(x, y)

Arguments

x
vector values of independent variable, usually time
y
vector values of dependent variable, usually concentration

Value

Details

With time-concentration curve, you frequently need to estimate slope in log(concentration) ~ time. This function is usually called by BestSlope function and you seldom need to call this function directly.

See Also

BestSlope

Examples

Run this code
Slope(Indometh[Indometh$Subject==1, "time"],Indometh[Indometh$Subject==1, "conc"])

Run the code above in your browser using DataLab