It calculates the slope with linear regression of log(y) ~ x
Usage
Slope(x, y)
Arguments
x
vector values of independent variable, usually time
y
vector values of dependent variable, usually concentration
Value
Details
With time-concentration curve, you frequently need to estimate slope in log(concentration) ~ time.
This function is usually called by BestSlope function and you seldom need to call this function directly.